gRPC Server Reflection support for xDS services.
This module provides gRPC reflection capabilities, allowing clients to
discover available services and their message types at runtime. This is
especially useful for debugging and tooling like grpcurl.
Example
use xds_server::reflection::ReflectionService;
// Create a reflection service with no encoded file descriptors
// (pass `&[encoded_fds]` to advertise specific services).
let _reflection = ReflectionService::new(&[]);Structs
- Reflection
Config - Configuration for the gRPC reflection service.
- Reflection
Service reflection - Service for gRPC server reflection.