ReflectionService

Struct ReflectionService 

pub struct ReflectionService { /* private fields */ }
Available on crate feature reflection only.
Service for gRPC server reflection.

This wraps tonic-reflection to provide service discovery capabilities.

Implementations

Source

impl ReflectionService

pub fn new(file_descriptor_sets: &[&'static [u8]]) -> Self

Create a new reflection service with the given file descriptor sets.

pub fn with_config(config: ReflectionConfig) -> Self

Create a new reflection service with a configuration.

pub fn build_server( &self, ) -> Option<ServerReflectionServer<impl ServerReflection>>

Build the reflection server.

Returns None if reflection is disabled or no file descriptors are provided.

pub fn build_server_v1alpha( &self, ) -> Option<ServerReflectionServer<impl ServerReflection>>

Build the reflection server (v1alpha version for older clients).

Returns None if reflection is disabled or no file descriptors are provided.