Module services

Module services 

gRPC service implementations for xDS.

This module contains the tonic service implementations for:

  • Aggregated Discovery Service (ADS)
  • Cluster Discovery Service (CDS)
  • Listener Discovery Service (LDS)
  • Route Discovery Service (RDS)
  • Endpoint Discovery Service (EDS)
  • Secret Discovery Service (SDS)

Re-exports

pub use ads::AdsConfig;
pub use ads::AdsService;
pub use cds::CdsService;
pub use eds::EdsService;
pub use lds::LdsService;
pub use rds::RdsService;
pub use sds::SdsService;

Modules

ads
Aggregated Discovery Service (ADS) implementation.
cds
Cluster Discovery Service (CDS) implementation.
eds
Endpoint Discovery Service (EDS) implementation.
lds
Listener Discovery Service (LDS) implementation.
rds
Route Discovery Service (RDS) implementation.
sds
Secret Discovery Service (SDS) implementation.

Structs

AggregatedDiscoveryServiceServer
See https://github.com/envoyproxy/envoy-api#apis for a description of the role of ADS and how it is intended to be used by a management server. ADS requests have the same structure as their singleton xDS counterparts, but can multiplex many resource types on a single stream. The type_url in the DiscoveryRequest/DiscoveryResponse provides sufficient information to recover the multiplexed singleton APIs at the Envoy instance and management server.
ClusterDiscoveryServiceServer
Return list of all clusters this proxy will load balance to.
EndpointDiscoveryServiceServer
ListenerDiscoveryServiceServer
The Envoy instance initiates an RPC at startup to discover a list of listeners. Updates are delivered via streaming from the LDS server and consist of a complete update of all listeners. Existing connections will be allowed to drain from listeners that are no longer present.
RouteDiscoveryServiceServer
The resource_names field in DiscoveryRequest specifies a route configuration. This allows an Envoy configuration with multiple HTTP listeners (and associated HTTP connection manager filters) to use different route configurations. Each listener will bind its HTTP connection manager filter to a route table via this identifier.
SecretDiscoveryServiceServer
ServiceState
Shared state for all xDS services.

Traits

AggregatedDiscoveryService
Generated trait containing gRPC methods that should be implemented for use with AggregatedDiscoveryServiceServer.
ClusterDiscoveryService
Generated trait containing gRPC methods that should be implemented for use with ClusterDiscoveryServiceServer.
EndpointDiscoveryService
Generated trait containing gRPC methods that should be implemented for use with EndpointDiscoveryServiceServer.
ListenerDiscoveryService
Generated trait containing gRPC methods that should be implemented for use with ListenerDiscoveryServiceServer.
RouteDiscoveryService
Generated trait containing gRPC methods that should be implemented for use with RouteDiscoveryServiceServer.
SecretDiscoveryService
Generated trait containing gRPC methods that should be implemented for use with SecretDiscoveryServiceServer.