CdsService

Struct CdsService 

pub struct CdsService { /* private fields */ }
Cluster Discovery Service.

Implementations

Source

impl CdsService

pub fn new(cache: Arc<ShardedCache>, registry: Arc<ResourceRegistry>) -> Self

Create a new CDS service.

pub fn new_with_handlers( cache: Arc<ShardedCache>, registry: Arc<ResourceRegistry>, sotw_handler: Arc<SotwHandler>, delta_handler: Arc<DeltaHandler>, ) -> Self

Create a new CDS service with shared protocol handlers.

This allows sharing handlers across multiple services for better resource efficiency.

pub fn type_url() -> &'static str

Get the type URL for clusters.

pub fn cache(&self) -> &ShardedCache

Get a reference to the cache.

pub fn registry(&self) -> &ResourceRegistry

Get a reference to the registry.

pub fn into_service(self) -> ClusterDiscoveryServiceServer<Self>

Convert this service into a tonic service for use with Server::add_service.