Module rds

Module rds 

Route Discovery Service (RDS) implementation.

RDS provides route configuration to Envoy proxies.

Structs

DeltaDiscoveryRequest
DeltaDiscoveryResponse
DiscoveryRequest
DiscoveryResponse
RdsService
Route Discovery Service.
RouteDiscoveryServiceServer
The resource_names field in DiscoveryRequest specifies a route configuration. This allows an Envoy configuration with multiple HTTP listeners (and associated HTTP connection manager filters) to use different route configurations. Each listener will bind its HTTP connection manager filter to a route table via this identifier.

Traits

RouteDiscoveryService
Generated trait containing gRPC methods that should be implemented for use with RouteDiscoveryServiceServer.

Type Aliases

RdsDeltaResponseStream
Delta response stream type for RDS.
RdsResponseStream
Response stream type for RDS.