pub struct RouteDiscoveryServiceServer<T> { /* private fields */ }Expand description
The resource_names field in DiscoveryRequest specifies a route configuration. This allows an Envoy configuration with multiple HTTP listeners (and associated HTTP connection manager filters) to use different route configurations. Each listener will bind its HTTP connection manager filter to a route table via this identifier.
Implementations
Sourceimpl<T> RouteDiscoveryServiceServer<T>
impl<T> RouteDiscoveryServiceServer<T>
pub fn new(inner: T) -> RouteDiscoveryServiceServer<T>
pub fn from_arc(inner: Arc<T>) -> RouteDiscoveryServiceServer<T>
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> InterceptedService<RouteDiscoveryServiceServer<T>, F>where
F: Interceptor,
Sourcepub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> RouteDiscoveryServiceServer<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> RouteDiscoveryServiceServer<T>
Enable decompressing requests with the given encoding.
Sourcepub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> RouteDiscoveryServiceServer<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> RouteDiscoveryServiceServer<T>
Compress responses with the given encoding, if the client supports it.
Sourcepub fn max_decoding_message_size(
self,
limit: usize,
) -> RouteDiscoveryServiceServer<T>
pub fn max_decoding_message_size( self, limit: usize, ) -> RouteDiscoveryServiceServer<T>
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(
self,
limit: usize,
) -> RouteDiscoveryServiceServer<T>
pub fn max_encoding_message_size( self, limit: usize, ) -> RouteDiscoveryServiceServer<T>
Limits the maximum size of an encoded message.
Default: usize::MAX