EndpointDiscoveryService

Trait EndpointDiscoveryService 

pub trait EndpointDiscoveryService:
    Send
    + Sync
    + 'static {
    type StreamEndpointsStream: Stream<Item = Result<DiscoveryResponse, Status>> + Send + 'static;
    type DeltaEndpointsStream: Stream<Item = Result<DeltaDiscoveryResponse, Status>> + Send + 'static;

    // Required methods
    fn stream_endpoints<'life0, 'async_trait>(
        &'life0 self,
        request: Request<Streaming<DiscoveryRequest>>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Self::StreamEndpointsStream>, Status>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
    fn delta_endpoints<'life0, 'async_trait>(
        &'life0 self,
        request: Request<Streaming<DeltaDiscoveryRequest>>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DeltaEndpointsStream>, Status>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
    fn fetch_endpoints<'life0, 'async_trait>(
        &'life0 self,
        request: Request<DiscoveryRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<DiscoveryResponse>, Status>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
}
Generated trait containing gRPC methods that should be implemented for use with EndpointDiscoveryServiceServer.

Required Associated Types

type StreamEndpointsStream: Stream<Item = Result<DiscoveryResponse, Status>> + Send + 'static

Server streaming response type for the StreamEndpoints method.

type DeltaEndpointsStream: Stream<Item = Result<DeltaDiscoveryResponse, Status>> + Send + 'static

Server streaming response type for the DeltaEndpoints method.

Required Methods

fn stream_endpoints<'life0, 'async_trait>( &'life0 self, request: Request<Streaming<DiscoveryRequest>>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::StreamEndpointsStream>, Status>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

The resource_names field in DiscoveryRequest specifies a list of clusters to subscribe to updates for.

fn delta_endpoints<'life0, 'async_trait>( &'life0 self, request: Request<Streaming<DeltaDiscoveryRequest>>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::DeltaEndpointsStream>, Status>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

fn fetch_endpoints<'life0, 'async_trait>( &'life0 self, request: Request<DiscoveryRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<DiscoveryResponse>, Status>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors