pub struct CdsService { /* private fields */ }Expand description
Cluster Discovery Service.
Implementations
Sourceimpl CdsService
impl CdsService
Sourcepub fn new(cache: Arc<ShardedCache>, registry: Arc<ResourceRegistry>) -> Self
pub fn new(cache: Arc<ShardedCache>, registry: Arc<ResourceRegistry>) -> Self
Create a new CDS service.
Sourcepub fn new_with_handlers(
cache: Arc<ShardedCache>,
registry: Arc<ResourceRegistry>,
sotw_handler: Arc<SotwHandler>,
delta_handler: Arc<DeltaHandler>,
) -> Self
pub fn new_with_handlers( cache: Arc<ShardedCache>, registry: Arc<ResourceRegistry>, sotw_handler: Arc<SotwHandler>, delta_handler: Arc<DeltaHandler>, ) -> Self
Create a new CDS service with shared protocol handlers.
This allows sharing handlers across multiple services for better resource efficiency.
Sourcepub fn cache(&self) -> &ShardedCache
pub fn cache(&self) -> &ShardedCache
Get a reference to the cache.
Sourcepub fn registry(&self) -> &ResourceRegistry
pub fn registry(&self) -> &ResourceRegistry
Get a reference to the registry.
Sourcepub fn into_service(self) -> ClusterDiscoveryServiceServer<Self>
pub fn into_service(self) -> ClusterDiscoveryServiceServer<Self>
Convert this service into a tonic service for use with Server::add_service.